@@ -25,7 +25,7 @@
 #include <QTime>
 
 #include <stepcore/world.h>
-#include <kundostack.h>
+#include <KActionCollection>
 
 namespace StepCore {
     class Object;
@@ -61,7 +61,7 @@ public:
     Q_DECLARE_FLAGS(UndoFlags, UndoFlag)
 
 public:
-    WorldModel(QObject* parent = 0);
+    explicit WorldModel(QObject* parent = 0);
     ~WorldModel();
 
     /** Get QItemSelectionModel associated with this WorldModel */
